==> nextcloud-24.0.10.tgz: nextcloud/apps/twofactor_backupcodes/l10n/da.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Du har lavet two-factor backup koder til din konto.",
    "Second-factor backup codes" : "Second-factor backup koder",
    "Generate backup codes" : "Generer backup-koder",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Du har aktiveret to-faktor-godkendelse, men har ikke genereret backup-koder endnu. De er nødvendige for at gendanne adgangen til din konto, hvis du mister din anden faktor.",
    "Backup code" : "Backup-kode",
    "Use backup code" : "Benyt backup-kode",
    "Two factor backup codes" : "To faktor backup koder",
    "A two-factor auth backup codes provider" : "En to-faktor udbyder af sikkerhedskopieringskoder",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Sikkerhedskopieringskoder er blevet genereret. {used} af {total} koder er blevet brugt.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Dett er dine backup koder. Gem eller udskriv dem venligst da det ikke vil være muligt at læse koderne her igen senere.",
    "Save backup codes" : "Gem backup-koder",
    "Print backup codes" : "Print backup-koder",
    "Regenerate backup codes" : "Regenerer backup-koder",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Hvis du genere nye backup koder vil de gamle koder blive ubrugelige.",
    "An error occurred while generating your backup codes" : "Der opstod en fejl under genereringen af dine backup-koder",
    "{name} backup codes" : "{name} backup-koder",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Brug en af de backupkoder, du har gemt, når du konfigurerer to-faktor-godkendelse.",
    "Submit" : "Tilføj"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.1.11.tgz: nextcloud/apps/twofactor_backupcodes/l10n/da.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Du har lavet two-factor backup koder til din konto",
    "Second-factor backup codes" : "Second-factor backup koder",
    "Generate backup codes" : "Generer backup koder",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Du har aktiveret to-faktor-godkendelse, men har ikke genereret backup-koder endnu. De er nødvendige for at gendanne adgang til din konto, hvis du mister din anden faktor.",
    "Backup code" : "Backup-kode",
    "Use backup code" : "Benyt backup-kode",
    "Two factor backup codes" : "To faktor backup koder",
    "A two-factor auth backup codes provider" : "En to-faktor udbyder af sikkerhedskopieringskoder",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Sikkerhedskopieringskoder er blevet genereret. {used} af {total} koder er blevet brugt.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Dett er dine backup koder. Gem eller udskriv dem venligst da det ikke vil være muligt at læse koderne her igen senere.",
    "Save backup codes" : "Gem backup-koder",
    "Print backup codes" : "Print backup-koder",
    "Regenerate backup codes" : "Regenerer backup-koder",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Hvis du genere nye backup koder vil de gamle koder blive ubrugelige.",
    "An error occurred while generating your backup codes" : "Der opstod en fejl under genereringen af dine backup-koder",
    "{name} backup codes" : "{name} backup-koder",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Brug en af de backupkoder, du har gemt, når du konfigurerer to-faktor-godkendelse.",
    "Submit" : "Tilføj"
},
"nplurals=2; plural=(n != 1);");
